@@ -4,7 +4,7 @@ class NamedEntity(Entity):
     """ A Named Entity representing system/SIMOS/NamedEntity"""
 
     def __init__(self) -> None:
-        self.__name = ""
+        self.__name = None
 
     @property
     def name(self) -> str:
